#include <NdbApi.hpp>
#include <stdio.h>
#include <string.h>

int main()
{
  ndb_init();

  Ndb_cluster_connection cluster_connection;

  if (cluster_connection.connect(4, 5, 1))
  {  
      printf("Can't connect to cluster\n");
      exit(-1);
  }
    
  if (cluster_connection.wait_until_ready(30,0) < 0)
    {
      printf("Cluster was not ready within 30 secs.\n");
      exit(-1);
    }

  Ndb myNdb( &cluster_connection, "test" );

  if (myNdb.init()) {
	  printf("couldn't get to test database\n");
	  exit(-1);
  }

  const NdbDictionary::Dictionary* myDict= myNdb.getDictionary();

  const NdbDictionary::Table *myTable= myDict->getTable("ndb_test");
  if (myTable == NULL) {
	  printf("Couldn't find table ndb_test");
	  exit(-1);
  }

  NdbTransaction *myTransaction= myNdb.startTransaction();

  NdbOperation *myOperation= myTransaction->getNdbOperation(myTable);

  myOperation->readTuple(NdbOperation::LM_Read);

  // this works fine with a CHAR(32) column
  // but brings all nodes down with VARCHAR(32)
  myOperation->equal("id", "2                               ");

#if 0
  // this code works with a VARCHAR(32)
  char tmp[32];
  tmp[0] = sprintf(tmp+1, "2");
  myOperation->equal("id", tmp);
#endif

  NdbRecAttr *myRecAttr= myOperation->getValue("keyid", NULL);

  if(myTransaction->execute( NdbTransaction::Commit ) == -1) {	
	  printf("Error %d: %s\n", myTransaction->getNdbError().code, myTransaction->getNdbError().message);
	  exit(-1);
  }
	
  printf(" %s    %lld\n", "2", myRecAttr->u_64_value());

  myNdb.closeTransaction(myTransaction);
  ndb_end(0);
  return 0;
}

